@@ -30,10 +30,14 @@
 /* after compilation, rename executable as `kxvt' */
 #undef KANJI
 
-/* Define if you want chinese support */
+/* Define if you want Chinese BIG5 support */
 /* after compilation, rename executable as `crxvt' */
 #undef ZH
 
+/* Define if you want Chinese GB (zh_CN i.e. GB2312) support */
+/* after compilation, rename executable as `gbxvt' */
+#undef ZHCN
+
 /* Define if Xlocale support doesn't work */
 #undef NO_XLOCALE
 
@@ -68,6 +72,10 @@
 /* Define if you want tty's to be setgid() to the `tty' group */
 #undef TTY_GID_SUPPORT
 
+/* Define if you want to have XIM (X Input Method) protocol support
+ * This is required for multibyte characters input. */
+#undef USE_XIM
+
 /* Define if you want to have utmp/utmpx support */
 #undef UTMP_SUPPORT
 
@@ -77,6 +85,9 @@
 /* Define if you want to have sexy-looking background pixmaps. Needs libXpm */
 #undef XPM_BACKGROUND
 
+/* Define if you want your background use the parent window background */
+#undef TRANSPARENT
+
 /* Define if you include <X11/xpm.h> on a normal include path (be careful) */
 #undef XPM_INC_X11
 
@@ -127,10 +138,18 @@
 /* Define if you need function prototypes */
 #undef PROTOTYPES
 
-/* type of (normal and unsigned) 16 bit, 32 bit and pointer */
-#undef RINT16T
-#undef RUINT16T
-#undef RINT32T
-#undef RUINT32T
-#undef RINTPT
-#undef RUINTPT
+/* Define if you have XPointer typedef */
+#undef HAVE_XPOINTER
+
+/* Define if you have _GNU_SOURCE getpt() */
+#undef HAVE_GETPT
+
+/* Define possible pty types */
+#undef PTYS_ARE_NUMERIC
+#undef PTYS_ARE_PTMX
+#undef PTYS_ARE_PTC
+#undef PTYS_ARE__GETPTY
+#undef PTYS_ARE_GETPTY
+#undef PTYS_ARE_GETPT
+#undef PTYS_ARE_CLONE
+#undef PTYS_ARE_SEARCHED
