@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	command.c
  *----------------------------------------------------------------------*
- * $Id: command.c,v 1.85.2.25 2000/01/04 11:20:02 mason Exp $
+ * $Id: command.c,v 1.85.2.30 2000/07/05 08:58:17 gcw Exp $
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (C) 1992      John Bovey, University of Kent at Canterbury <jdb@ukc.ac.uk>
@@ -74,7 +74,7 @@ static Atom     wmDeleteWindow;
 static Atom     DndProtocol, DndSelection;
 #endif				/* OFFIX_DND */
 
-#ifndef NO_XLOCALE
+#ifdef USE_XIM
 static XIC      Input_Context;	/* input context */
 #endif				/* NO_XLOCALE */
 
@@ -996,9 +996,7 @@ init_xlocale(void)
     else {
     /* To avoid Segmentation Fault in C locale */
 	setTermFontSet();
-#ifdef MULTICHAR_SET
         if (strcmp(locale, "C"))
-#endif
 	    XRegisterIMInstantiateCallback(Xdisplay, NULL, NULL, NULL,
 					   IMInstantiateCallback, NULL);
     }
@@ -1094,9 +1092,6 @@ lookup_key(XEvent * ev)
     }
 #endif				/* USE_XIM */
 
-    if (len && (Options & Opt_scrollKeypress))
-	TermWin.view_start = 0;
-
 #ifdef USE_XIM
     if (valid_keysym) {
 #endif
@@ -1510,6 +1505,11 @@ lookup_key(XEvent * ev)
     if (len <= 0)
 	return;			/* not mapped */
 
+    if (Options & Opt_scrollKeypress) {
+	want_refresh |= TermWin.view_start;
+	TermWin.view_start = 0;
+    }
+
 /*
  * these modifications only affect the static keybuffer
  * pass Shift/Control indicators for function keys ending with `~'
@@ -1890,7 +1890,7 @@ process_x_event(XEvent * ev)
 	if (!TermWin.focus) {
 	    TermWin.focus = 1;
 	    want_refresh = 1;
-#ifndef NO_XLOCALE
+#if !defined(NO_XLOCALE) && defined(USE_XIM)
 	    if (Input_Context != NULL)
 		XSetICFocus(Input_Context);
 #endif
@@ -1901,7 +1901,7 @@ process_x_event(XEvent * ev)
 	if (TermWin.focus) {
 	    TermWin.focus = 0;
 	    want_refresh = 1;
-#ifndef NO_XLOCALE
+#if !defined(NO_XLOCALE) && defined(USE_XIM)
 	    if (Input_Context != NULL)
 		XUnsetICFocus(Input_Context);
 #endif
