@@ -1,6 +1,6 @@
 /*
  * File:	feature.h
- * $Id: feature.h,v 1.20.2.7 1999/12/12 10:15:22 mason Exp $
+ * $Id: feature.h,v 1.20.2.9 2000/07/05 07:26:17 gcw Exp $
  *
  * Compile-time configuration.
  *-----------------------------------------------------------------------
@@ -79,6 +79,12 @@
  */
 #define PREFER_24BIT
 
+/*
+ * Define maximum possible columns and rows
+ */
+#define MAX_COLS	400
+#define MAX_ROWS	300
+
 /*
  * Define default colours for certain items.  If you have a low colour
  * display, then consider using colours which are already pre-allocated:
@@ -315,7 +321,7 @@
 /*
  * Force local connection to be socket (or other local) communication
  */
-#define LOCAL_X_IS_UNIX
+/* #define LOCAL_X_IS_UNIX */
 
 /*
  * Have DISPLAY environment variable & "\E[7n" transmit display with IP number
