@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	main.c
  *----------------------------------------------------------------------*
- * $Id: main.c,v 1.66.2.10 2000/01/26 23:31:19 mason Exp $
+ * $Id: main.c,v 1.66.2.11 2000/06/04 06:47:32 gcw Exp $
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (C) 1992      John Bovey, University of Canterbury
@@ -533,6 +533,14 @@ resize_window(unsigned int width, unsigned int height)
 
     new_ncol = (width - szHint.base_width) / TermWin.fwidth;
     new_nrow = (height - szHint.base_height) / TermWin.fheight;
+    if (new_ncol > MAX_COLS) {
+	new_ncol = MAX_COLS;
+	width = (MAX_COLS * TermWin.fwidth) + szHint.base_width;
+    }
+    if (new_nrow > MAX_ROWS) {
+	new_nrow = MAX_ROWS;
+	height = (MAX_ROWS * TermWin.fheight) + szHint.base_height;
+    }
     if (old_height == -1
 	|| (new_ncol != TermWin.ncol)
 	|| (new_nrow != TermWin.nrow)) {
@@ -567,6 +575,8 @@ set_widthheight(unsigned int width, unsigned int height)
 {
     XWindowAttributes wattr;
 
+    MIN_IT(width, (MAX_COLS * TermWin.fwidth));
+    MIN_IT(height, (MAX_ROWS * TermWin.fheight));
     if (width == 0 || height == 0) {
 	XGetWindowAttributes(Xdisplay, Xroot, &wattr);
 	if (width == 0)
@@ -603,11 +613,11 @@ szhints_set(void)
 	     XParseGeometry(rs[Rs_geometry], &x, &y, &width, &height) : 0);
 
     if (flags & WidthValue) {
-	TermWin.ncol = width;
+	TermWin.ncol = min(width, MAX_COLS);
 	szHint.flags |= USSize;
     }
     if (flags & HeightValue) {
-	TermWin.nrow = height;
+	TermWin.nrow = min(height, MAX_ROWS);
 	szHint.flags |= USSize;
     }
     TermWin.width = TermWin.ncol * TermWin.fwidth;
